==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/UwagiRealizacjaPlanu.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class UwagiRealizacjaPlanu extends GenericDPSObject {
    /**
     * UWAGI_REALIZACJA_PLANU.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * UWAGI_REALIZACJA_PLANU.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long planWsparciaRealizacjaId;

    /**
     * UWAGI_REALIZACJA_PLANU.UWAGI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String uwagi;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UWAGI_REALIZACJA_PLANU.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UWAGI_REALIZACJA_PLANU.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UWAGI_REALIZACJA_PLANU.PLAN_WSPARCIA_REALIZACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPlanWsparciaRealizacjaId() {
        return planWsparciaRealizacjaId;
    }

    /**
     * UWAGI_REALIZACJA_PLANU.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @param planWsparciaRealizacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPlanWsparciaRealizacjaId(Long planWsparciaRealizacjaId) {
        this.planWsparciaRealizacjaId = planWsparciaRealizacjaId;
    }

    /**
     * @return UWAGI_REALIZACJA_PLANU.UWAGI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * UWAGI_REALIZACJA_PLANU.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UwagiRealizacjaPlanu other = (UwagiRealizacjaPlanu) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPlanWsparciaRealizacjaId() == null ? other.getPlanWsparciaRealizacjaId() == null : this.getPlanWsparciaRealizacjaId().equals(other.getPlanWsparciaRealizacjaId()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPlanWsparciaRealizacjaId() == null) ? 0 : getPlanWsparciaRealizacjaId().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", planWsparciaRealizacjaId=").append(planWsparciaRealizacjaId);
        sb.append(", uwagi=").append(uwagi);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/UwagiRealizacjaPlanu.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class UwagiRealizacjaPlanu extends GenericDPSObject {
    /**
     * UWAGI_REALIZACJA_PLANU.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * UWAGI_REALIZACJA_PLANU.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long planWsparciaRealizacjaId;

    /**
     * UWAGI_REALIZACJA_PLANU.UWAGI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String uwagi;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UWAGI_REALIZACJA_PLANU.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UWAGI_REALIZACJA_PLANU.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UWAGI_REALIZACJA_PLANU.PLAN_WSPARCIA_REALIZACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPlanWsparciaRealizacjaId() {
        return planWsparciaRealizacjaId;
    }

    /**
     * UWAGI_REALIZACJA_PLANU.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @param planWsparciaRealizacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPlanWsparciaRealizacjaId(Long planWsparciaRealizacjaId) {
        this.planWsparciaRealizacjaId = planWsparciaRealizacjaId;
    }

    /**
     * @return UWAGI_REALIZACJA_PLANU.UWAGI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * UWAGI_REALIZACJA_PLANU.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UwagiRealizacjaPlanu other = (UwagiRealizacjaPlanu) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPlanWsparciaRealizacjaId() == null ? other.getPlanWsparciaRealizacjaId() == null : this.getPlanWsparciaRealizacjaId().equals(other.getPlanWsparciaRealizacjaId()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPlanWsparciaRealizacjaId() == null) ? 0 : getPlanWsparciaRealizacjaId().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", planWsparciaRealizacjaId=").append(planWsparciaRealizacjaId);
        sb.append(", uwagi=").append(uwagi);
        sb.append("]");
        return sb.toString();
    }
}
